import requests


class ComputeClient:
    def __init__(self, api_key, base_url="https://api.lumaserv.com/compute"):
        self.base_url = base_url
        self.session = requests.Session()
        self.session.headers.update({
            'Authorization': 'Bearer ' + api_key,
            'Content-Type': 'application/json'
        })


    def request(self, method, path, params={}, body={}):
        r = self.session.request(method, self.base_url + path, json=body, params=params)
        if r.status_code < 200 or (r.status_code >= 300 and r.status_code < 400):
            raise Exception("Status code is " + r.status_code + "!")
        return r.json()


    def create_ssh_key(self, body, query_params={}):
        return self.request("POST", "/ssh-keys", query_params, body)


    def get_ssh_keys(self, query_params={}):
        return self.request("GET", "/ssh-keys", query_params)


    def create_server_price_range(self, body, query_params={}):
        return self.request("POST", "/server-price-ranges", query_params, body)


    def get_server_price_ranges(self, query_params={}):
        return self.request("GET", "/server-price-ranges", query_params)


    def start_server(self, id, query_params={}):
        return self.request("POST", "/servers/{id}/start".format(id=id), query_params)


    def create_availability_zone(self, body, query_params={}):
        return self.request("POST", "/availability-zones", query_params, body)


    def get_availability_zones(self, query_params={}):
        return self.request("GET", "/availability-zones", query_params)


    def get_server_template(self, id, query_params={}):
        return self.request("GET", "/server-templates/{id}".format(id=id), query_params)


    def shutdown_server(self, id, query_params={}):
        return self.request("POST", "/servers/{id}/shutdown".format(id=id), query_params)


    def get_server_firewall(self, id, query_params={}):
        return self.request("GET", "/server-firewalls/{id}".format(id=id), query_params)


    def delete_server_firewall(self, id, query_params={}):
        return self.request("DELETE", "/server-firewalls/{id}".format(id=id), query_params)


    def get_server(self, id, query_params={}):
        return self.request("GET", "/servers/{id}".format(id=id), query_params)


    def delete_server(self, id, query_params={}):
        return self.request("DELETE", "/servers/{id}".format(id=id), query_params)


    def update_server(self, id, body, query_params={}):
        return self.request("PUT", "/servers/{id}".format(id=id), query_params, body)


    def get_server_actions(self, query_params={}):
        return self.request("GET", "/server-actions", query_params)


    def get_server_storage_class(self, id, query_params={}):
        return self.request("GET", "/server-storage-classes/{id}".format(id=id), query_params)


    def restart_server(self, id, query_params={}):
        return self.request("POST", "/servers/{id}/restart".format(id=id), query_params)


    def mount_server_media(self, id, body, query_params={}):
        return self.request("POST", "/servers/{id}/mount".format(id=id), query_params, body)


    def unmount_server_media(self, id, query_params={}):
        return self.request("DELETE", "/servers/{id}/mount".format(id=id), query_params)


    def restore_server(self, id, body, query_params={}):
        return self.request("POST", "/servers/{id}/restore".format(id=id), query_params, body)


    def get_server_graph(self, id, query_params={}):
        return self.request("GET", "/servers/{id}/graph".format(id=id), query_params)


    def recreate_server(self, id, query_params={}):
        return self.request("POST", "/servers/{id}/recreate".format(id=id), query_params)


    def create_server_firewall(self, body, query_params={}):
        return self.request("POST", "/server-firewalls", query_params, body)


    def get_server_firewalls(self, query_params={}):
        return self.request("GET", "/server-firewalls", query_params)


    def get_server_firewall_rule(self, id, rule_id, query_params={}):
        return self.request("GET", "/server-firewalls/{id}/rules/{rule_id}".format(id=id, rule_id=rule_id), query_params)


    def delete_server_firewall_rule(self, id, rule_id, query_params={}):
        return self.request("DELETE", "/server-firewalls/{id}/rules/{rule_id}".format(id=id, rule_id=rule_id), query_params)


    def update_server_firewall_rule(self, id, rule_id, body, query_params={}):
        return self.request("PUT", "/server-firewalls/{id}/rules/{rule_id}".format(id=id, rule_id=rule_id), query_params, body)


    def create_server_host(self, body, query_params={}):
        return self.request("POST", "/server-hosts", query_params, body)


    def get_server_hosts(self, query_params={}):
        return self.request("GET", "/server-hosts", query_params)


    def create_server(self, body, query_params={}):
        return self.request("POST", "/servers", query_params, body)


    def get_servers(self, query_params={}):
        return self.request("GET", "/servers", query_params)


    def delete_server_network(self, id, network_id, query_params={}):
        return self.request("DELETE", "/servers/{id}/networks/{network_id}".format(id=id, network_id=network_id), query_params)


    def get_availability_zone(self, id, query_params={}):
        return self.request("GET", "/availability-zones/{id}".format(id=id), query_params)


    def update_availability_zone(self, id, body, query_params={}):
        return self.request("PUT", "/availability-zones/{id}".format(id=id), query_params, body)


    def create_server_backup(self, body, query_params={}):
        return self.request("POST", "/server-backups", query_params, body)


    def get_server_backups(self, query_params={}):
        return self.request("GET", "/server-backups", query_params)


    def create_subnet(self, body, query_params={}):
        return self.request("POST", "/subnets", query_params, body)


    def get_subnets(self, query_params={}):
        return self.request("GET", "/subnets", query_params)


    def create_server_volume(self, body, query_params={}):
        return self.request("POST", "/server-volumes", query_params, body)


    def get_server_volumes(self, query_params={}):
        return self.request("GET", "/server-volumes", query_params)


    def create_server_storage_class(self, body, query_params={}):
        return self.request("POST", "/server-storage-classes", query_params, body)


    def get_server_storage_classes(self, query_params={}):
        return self.request("GET", "/server-storage-classes", query_params)


    def get_server_firewall_member(self, id, member_id, query_params={}):
        return self.request("GET", "/server-firewalls/{id}/members/{member_id}".format(id=id, member_id=member_id), query_params)


    def delete_server_firewall_member(self, id, member_id, query_params={}):
        return self.request("DELETE", "/server-firewalls/{id}/members/{member_id}".format(id=id, member_id=member_id), query_params)


    def search(self, query_params={}):
        return self.request("GET", "/search", query_params)


    def get_scheduled_server_action(self, id, action_id, query_params={}):
        return self.request("GET", "/servers/{id}/scheduled-actions/{action_id}".format(id=id, action_id=action_id), query_params)


    def delete_scheduled_server_action(self, id, action_id, query_params={}):
        return self.request("DELETE", "/servers/{id}/scheduled-actions/{action_id}".format(id=id, action_id=action_id), query_params)


    def update_scheduled_server_action(self, id, action_id, body, query_params={}):
        return self.request("PUT", "/servers/{id}/scheduled-actions/{action_id}".format(id=id, action_id=action_id), query_params, body)


    def create_s3_bucket(self, body, query_params={}):
        return self.request("POST", "/storage/s3/buckets", query_params, body)


    def get_s3_buckets(self, query_params={}):
        return self.request("GET", "/storage/s3/buckets", query_params)


    def get_server_status(self, id, query_params={}):
        return self.request("GET", "/servers/{id}/status".format(id=id), query_params)


    def create_server_firewall_member(self, id, body, query_params={}):
        return self.request("POST", "/server-firewalls/{id}/members".format(id=id), query_params, body)


    def get_server_firewall_members(self, id, query_params={}):
        return self.request("GET", "/server-firewalls/{id}/members".format(id=id), query_params)


    def get_server_price_range(self, id, query_params={}):
        return self.request("GET", "/server-price-ranges/{id}".format(id=id), query_params)


    def get_server_action(self, id, query_params={}):
        return self.request("GET", "/server-actions/{id}".format(id=id), query_params)


    def get_server_variant_price(self, id, variant_id, query_params={}):
        return self.request("GET", "/server-price-ranges/{id}/variant-prices/{variant_id}".format(id=id, variant_id=variant_id), query_params)


    def delete_server_variant_price(self, id, variant_id, query_params={}):
        return self.request("DELETE", "/server-price-ranges/{id}/variant-prices/{variant_id}".format(id=id, variant_id=variant_id), query_params)


    def update_server_variant_price(self, id, variant_id, body, query_params={}):
        return self.request("PUT", "/server-price-ranges/{id}/variant-prices/{variant_id}".format(id=id, variant_id=variant_id), query_params, body)


    def create_server_template(self, body, query_params={}):
        return self.request("POST", "/server-templates", query_params, body)


    def get_server_templates(self, query_params={}):
        return self.request("GET", "/server-templates", query_params)


    def get_server_host(self, id, query_params={}):
        return self.request("GET", "/server-hosts/{id}".format(id=id), query_params)


    def update_server_host(self, id, body, query_params={}):
        return self.request("PUT", "/server-hosts/{id}".format(id=id), query_params, body)


    def create_server_firewall_rule(self, id, body, query_params={}):
        return self.request("POST", "/server-firewalls/{id}/rules".format(id=id), query_params, body)


    def get_server_firewall_rules(self, id, query_params={}):
        return self.request("GET", "/server-firewalls/{id}/rules".format(id=id), query_params)


    def create_scheduled_server_action(self, id, body, query_params={}):
        return self.request("POST", "/servers/{id}/scheduled-actions".format(id=id), query_params, body)


    def get_scheduled_server_actions(self, id, query_params={}):
        return self.request("GET", "/servers/{id}/scheduled-actions".format(id=id), query_params)


    def stop_server(self, id, query_params={}):
        return self.request("POST", "/servers/{id}/stop".format(id=id), query_params)


    def get_server_volume(self, id, query_params={}):
        return self.request("GET", "/server-volumes/{id}".format(id=id), query_params)


    def delete_server_volume(self, id, query_params={}):
        return self.request("DELETE", "/server-volumes/{id}".format(id=id), query_params)


    def update_server_volume(self, id, body, query_params={}):
        return self.request("PUT", "/server-volumes/{id}".format(id=id), query_params, body)


    def create_server_network(self, id, body, query_params={}):
        return self.request("POST", "/servers/{id}/networks".format(id=id), query_params, body)


    def get_server_networks(self, id, query_params={}):
        return self.request("GET", "/servers/{id}/networks".format(id=id), query_params)


    def create_server_variant(self, body, query_params={}):
        return self.request("POST", "/server-variants", query_params, body)


    def get_server_variants(self, query_params={}):
        return self.request("GET", "/server-variants", query_params)


    def get_server_storage(self, id, query_params={}):
        return self.request("GET", "/server-storages/{id}".format(id=id), query_params)


    def get_ssh_key(self, id, query_params={}):
        return self.request("GET", "/ssh-keys/{id}".format(id=id), query_params)


    def delete_ssh_key(self, id, query_params={}):
        return self.request("DELETE", "/ssh-keys/{id}".format(id=id), query_params)


    def update_ssh_key(self, id, body, query_params={}):
        return self.request("PUT", "/ssh-keys/{id}".format(id=id), query_params, body)


    def create_server_price_range_assignment(self, body, query_params={}):
        return self.request("POST", "/server-price-range-assignments", query_params, body)


    def get_server_price_range_assignments(self, query_params={}):
        return self.request("GET", "/server-price-range-assignments", query_params)


    def get_addresses(self, query_params={}):
        return self.request("GET", "/addresses", query_params)


    def get_server_variant(self, id, query_params={}):
        return self.request("GET", "/server-variants/{id}".format(id=id), query_params)


    def delete_server_variant(self, id, query_params={}):
        return self.request("DELETE", "/server-variants/{id}".format(id=id), query_params)


    def delete_s3_access_key_grant(self, access_key_id, id, query_params={}):
        return self.request("DELETE", "/storage/s3/access-keys/{access_key_id}/grants/{id}".format(access_key_id=access_key_id, id=id), query_params)


    def create_server_media(self, body, query_params={}):
        return self.request("POST", "/server-medias", query_params, body)


    def get_server_medias(self, query_params={}):
        return self.request("GET", "/server-medias", query_params)


    def get_subnet(self, id, query_params={}):
        return self.request("GET", "/subnets/{id}".format(id=id), query_params)


    def delete_subnet(self, id, query_params={}):
        return self.request("DELETE", "/subnets/{id}".format(id=id), query_params)


    def attach_server_volume(self, id, body, query_params={}):
        return self.request("POST", "/server-volumes/{id}/attach".format(id=id), query_params, body)


    def get_s3_access_key(self, id, query_params={}):
        return self.request("GET", "/storage/s3/access-keys/{id}".format(id=id), query_params)


    def delete_s3_access_key(self, id, query_params={}):
        return self.request("DELETE", "/storage/s3/access-keys/{id}".format(id=id), query_params)


    def create_s3_access_key(self, body, query_params={}):
        return self.request("POST", "/storage/s3/access-keys", query_params, body)


    def get_s3_access_keys(self, query_params={}):
        return self.request("GET", "/storage/s3/access-keys", query_params)


    def get_address(self, id, query_params={}):
        return self.request("GET", "/addresses/{id}".format(id=id), query_params)


    def get_server_backup(self, id, query_params={}):
        return self.request("GET", "/server-backups/{id}".format(id=id), query_params)


    def delete_server_backup(self, id, query_params={}):
        return self.request("DELETE", "/server-backups/{id}".format(id=id), query_params)


    def update_server_backup(self, id, body, query_params={}):
        return self.request("PUT", "/server-backups/{id}".format(id=id), query_params, body)


    def create_network(self, body, query_params={}):
        return self.request("POST", "/networks", query_params, body)


    def get_networks(self, query_params={}):
        return self.request("GET", "/networks", query_params)


    def create_server_storage(self, body, query_params={}):
        return self.request("POST", "/server-storages", query_params, body)


    def get_server_storages(self, query_params={}):
        return self.request("GET", "/server-storages", query_params)


    def resize_server(self, id, body, query_params={}):
        return self.request("POST", "/servers/{id}/resize".format(id=id), query_params, body)


    def get_server_media(self, id, query_params={}):
        return self.request("GET", "/server-medias/{id}".format(id=id), query_params)


    def delete_server_media(self, id, query_params={}):
        return self.request("DELETE", "/server-medias/{id}".format(id=id), query_params)


    def create_s3_access_key_grant(self, access_key_id, body, query_params={}):
        return self.request("POST", "/storage/s3/access-keys/{access_key_id}/grants".format(access_key_id=access_key_id), query_params, body)


    def get_s3_access_key_grants(self, access_key_id, query_params={}):
        return self.request("GET", "/storage/s3/access-keys/{access_key_id}/grants".format(access_key_id=access_key_id), query_params)


    def get_server_price_range_assignment(self, id, query_params={}):
        return self.request("GET", "/server-price-range-assignments/{id}".format(id=id), query_params)


    def delete_server_price_range_assignment(self, id, query_params={}):
        return self.request("DELETE", "/server-price-range-assignments/{id}".format(id=id), query_params)


    def update_server_price_range_assignment(self, id, body, query_params={}):
        return self.request("PUT", "/server-price-range-assignments/{id}".format(id=id), query_params, body)


    def get_server_vnc(self, id, query_params={}):
        return self.request("GET", "/servers/{id}/vnc".format(id=id), query_params)


    def cancel_server_action(self, id, query_params={}):
        return self.request("POST", "/server-actions/{id}/cancel".format(id=id), query_params)


    def get_network(self, id, query_params={}):
        return self.request("GET", "/networks/{id}".format(id=id), query_params)


    def update_network(self, id, body, query_params={}):
        return self.request("PUT", "/networks/{id}".format(id=id), query_params, body)


    def get_labels(self, query_params={}):
        return self.request("GET", "/labels", query_params)


    def resize_server_volume(self, id, body, query_params={}):
        return self.request("POST", "/server-volumes/{id}/resize".format(id=id), query_params, body)


    def get_s3_bucket(self, id, query_params={}):
        return self.request("GET", "/storage/s3/buckets/{id}".format(id=id), query_params)


    def delete_s3_bucket(self, id, query_params={}):
        return self.request("DELETE", "/storage/s3/buckets/{id}".format(id=id), query_params)


    def detach_server_volume(self, id, query_params={}):
        return self.request("POST", "/server-volumes/{id}/detach".format(id=id), query_params)


    def create_server_variant_price(self, id, body, query_params={}):
        return self.request("POST", "/server-price-ranges/{id}/variant-prices".format(id=id), query_params, body)


    def get_server_variant_prices(self, id, query_params={}):
        return self.request("GET", "/server-price-ranges/{id}/variant-prices".format(id=id), query_params)





import requests


class BillingClient:
    def __init__(self, api_key, base_url="https://api.lumaserv.com/billing"):
        self.base_url = base_url
        self.session = requests.Session()
        self.session.headers.update({
            'Authorization': 'Bearer ' + api_key,
            'Content-Type': 'application/json'
        })


    def request(self, method, path, params={}, body={}):
        r = self.session.request(method, self.base_url + path, json=body, params=params)
        if r.status_code < 200 or (r.status_code >= 300 and r.status_code < 400):
            raise Exception("Status code is " + r.status_code + "!")
        return r.json()


    def create_debit_mandate(self, body, query_params={}):
        return self.request("POST", "/debit-mandates", query_params, body)


    def get_debit_mandates(self, query_params={}):
        return self.request("GET", "/debit-mandates", query_params)


    def get_invoice_file(self, id, query_params={}):
        return self.request("GET", "/invoices/{id}/file".format(id=id), query_params)


    def create_invoice_position(self, id, body, query_params={}):
        return self.request("POST", "/invoices/{id}/positions".format(id=id), query_params, body)


    def get_invoice_positions(self, id, query_params={}):
        return self.request("GET", "/invoices/{id}/positions".format(id=id), query_params)


    def get_billing_position(self, id, query_params={}):
        return self.request("GET", "/billing-positions/{id}".format(id=id), query_params)


    def delete_billing_position(self, id, query_params={}):
        return self.request("DELETE", "/billing-positions/{id}".format(id=id), query_params)


    def update_billing_position(self, id, body, query_params={}):
        return self.request("PUT", "/billing-positions/{id}".format(id=id), query_params, body)


    def get_debit_mandate(self, id, query_params={}):
        return self.request("GET", "/debit-mandates/{id}".format(id=id), query_params)


    def create_billing_position(self, body, query_params={}):
        return self.request("POST", "/billing-positions", query_params, body)


    def get_billing_positions(self, query_params={}):
        return self.request("GET", "/billing-positions", query_params)


    def create_customer(self, body, query_params={}):
        return self.request("POST", "/customers", query_params, body)


    def get_customers(self, query_params={}):
        return self.request("GET", "/customers", query_params)


    def get_invoice_position(self, invoice_id, id, query_params={}):
        return self.request("GET", "/invoices/{invoice_id}/positions/{id}".format(invoice_id=invoice_id, id=id), query_params)


    def delete_invoice_position(self, invoice_id, id, query_params={}):
        return self.request("DELETE", "/invoices/{invoice_id}/positions/{id}".format(invoice_id=invoice_id, id=id), query_params)


    def update_invoice_position(self, invoice_id, id, body, query_params={}):
        return self.request("PUT", "/invoices/{invoice_id}/positions/{id}".format(invoice_id=invoice_id, id=id), query_params, body)


    def create_service_contract(self, body, query_params={}):
        return self.request("POST", "/service-contracts", query_params, body)


    def get_service_contracts(self, query_params={}):
        return self.request("GET", "/service-contracts", query_params)


    def get_debits(self, query_params={}):
        return self.request("GET", "/debits", query_params)


    def get_customer(self, id, query_params={}):
        return self.request("GET", "/customers/{id}".format(id=id), query_params)


    def update_customer(self, id, body, query_params={}):
        return self.request("PUT", "/customers/{id}".format(id=id), query_params, body)


    def get_invoice(self, id, query_params={}):
        return self.request("GET", "/invoices/{id}".format(id=id), query_params)


    def delete_invoice(self, id, query_params={}):
        return self.request("DELETE", "/invoices/{id}".format(id=id), query_params)


    def update_invoice(self, id, body, query_params={}):
        return self.request("PUT", "/invoices/{id}".format(id=id), query_params, body)


    def get_service_contract_position(self, contract_id, id, query_params={}):
        return self.request("GET", "/service-contracts/{contract_id}/positions/{id}".format(contract_id=contract_id, id=id), query_params)


    def delete_service_contract_position(self, contract_id, id, query_params={}):
        return self.request("DELETE", "/service-contracts/{contract_id}/positions/{id}".format(contract_id=contract_id, id=id), query_params)


    def update_service_contract_position(self, contract_id, id, body, query_params={}):
        return self.request("PUT", "/service-contracts/{contract_id}/positions/{id}".format(contract_id=contract_id, id=id), query_params, body)


    def create_invoice(self, body, query_params={}):
        return self.request("POST", "/invoices", query_params, body)


    def get_invoices(self, query_params={}):
        return self.request("GET", "/invoices", query_params)


    def get_debit(self, id, query_params={}):
        return self.request("GET", "/debits/{id}".format(id=id), query_params)


    def create_service_contract_position(self, contract_id, body, query_params={}):
        return self.request("POST", "/service-contracts/{contract_id}/positions".format(contract_id=contract_id), query_params, body)


    def get_service_contract_positions(self, contract_id, query_params={}):
        return self.request("GET", "/service-contracts/{contract_id}/positions".format(contract_id=contract_id), query_params)


    def get_service_contract(self, id, query_params={}):
        return self.request("GET", "/service-contracts/{id}".format(id=id), query_params)


    def delete_service_contract(self, id, query_params={}):
        return self.request("DELETE", "/service-contracts/{id}".format(id=id), query_params)


    def update_service_contract(self, id, body, query_params={}):
        return self.request("PUT", "/service-contracts/{id}".format(id=id), query_params, body)





import requests


class DomainClient:
    def __init__(self, api_key, base_url="https://api.lumaserv.com/domain"):
        self.base_url = base_url
        self.session = requests.Session()
        self.session.headers.update({
            'Authorization': 'Bearer ' + api_key,
            'Content-Type': 'application/json'
        })


    def request(self, method, path, params={}, body={}):
        r = self.session.request(method, self.base_url + path, json=body, params=params)
        if r.status_code < 200 or (r.status_code >= 300 and r.status_code < 400):
            raise Exception("Status code is " + r.status_code + "!")
        return r.json()


    def get_domain_handle(self, code, query_params={}):
        return self.request("GET", "/domain-handles/{code}".format(code=code), query_params)


    def delete_domain_handle(self, code, query_params={}):
        return self.request("DELETE", "/domain-handles/{code}".format(code=code), query_params)


    def update_domain_handle(self, code, body, query_params={}):
        return self.request("PUT", "/domain-handles/{code}".format(code=code), query_params, body)


    def unschedule_domain_delete(self, name, query_params={}):
        return self.request("POST", "/domains/{name}/unschedule-delete".format(name=name), query_params)


    def create_dns_zone_record(self, name, body, query_params={}):
        return self.request("POST", "/dns/zones/{name}/records".format(name=name), query_params, body)


    def get_dns_zone_records(self, name, query_params={}):
        return self.request("GET", "/dns/zones/{name}/records".format(name=name), query_params)


    def update_dns_zone_records(self, name, body, query_params={}):
        return self.request("PUT", "/dns/zones/{name}/records".format(name=name), query_params, body)


    def schedule_domain_delete(self, name, body, query_params={}):
        return self.request("POST", "/domains/{name}/schedule-delete".format(name=name), query_params, body)


    def search(self, query_params={}):
        return self.request("GET", "/search", query_params)


    def get_domain_pricing_list(self, query_params={}):
        return self.request("GET", "/pricing/domains", query_params)


    def get_domain_authinfo(self, name, query_params={}):
        return self.request("GET", "/domains/{name}/authinfo".format(name=name), query_params)


    def remove_domain_authinfo(self, name, query_params={}):
        return self.request("DELETE", "/domains/{name}/authinfo".format(name=name), query_params)


    def restore_domain(self, name, query_params={}):
        return self.request("POST", "/domains/{name}/restore".format(name=name), query_params)


    def get_dns_zones(self, query_params={}):
        return self.request("GET", "/dns/zones", query_params)


    def delete_dns_record(self, name, id, query_params={}):
        return self.request("DELETE", "/dns/zones/{name}/records/{id}".format(name=name, id=id), query_params)


    def update_dns_record(self, name, id, body, query_params={}):
        return self.request("PUT", "/dns/zones/{name}/records/{id}".format(name=name, id=id), query_params, body)


    def send_domain_verification(self, name, query_params={}):
        return self.request("POST", "/domains/{name}/verification".format(name=name), query_params)


    def check_domain_verification(self, name, query_params={}):
        return self.request("GET", "/domains/{name}/verification".format(name=name), query_params)


    def get_dns_zone(self, name, query_params={}):
        return self.request("GET", "/dns/zones/{name}".format(name=name), query_params)


    def update_dns_zone(self, name, body, query_params={}):
        return self.request("PUT", "/dns/zones/{name}".format(name=name), query_params, body)


    def get_labels(self, query_params={}):
        return self.request("GET", "/labels", query_params)


    def create_domain_handle(self, body, query_params={}):
        return self.request("POST", "/domain-handles", query_params, body)


    def get_domain_handles(self, query_params={}):
        return self.request("GET", "/domain-handles", query_params)


    def check_domain(self, name, query_params={}):
        return self.request("GET", "/domains/{name}/check".format(name=name), query_params)


    def create_domain(self, body, query_params={}):
        return self.request("POST", "/domains", query_params, body)


    def get_domains(self, query_params={}):
        return self.request("GET", "/domains", query_params)


    def get_domain(self, name, query_params={}):
        return self.request("GET", "/domains/{name}".format(name=name), query_params)


    def delete_domain(self, name, query_params={}):
        return self.request("DELETE", "/domains/{name}".format(name=name), query_params)


    def update_domain(self, name, body, query_params={}):
        return self.request("PUT", "/domains/{name}".format(name=name), query_params, body)





import requests


class AddonClient:
    def __init__(self, api_key, base_url="https://api.lumaserv.com/addon"):
        self.base_url = base_url
        self.session = requests.Session()
        self.session.headers.update({
            'Authorization': 'Bearer ' + api_key,
            'Content-Type': 'application/json'
        })


    def request(self, method, path, params={}, body={}):
        r = self.session.request(method, self.base_url + path, json=body, params=params)
        if r.status_code < 200 or (r.status_code >= 300 and r.status_code < 400):
            raise Exception("Status code is " + r.status_code + "!")
        return r.json()


    def create_ssl_certificate(self, body, query_params={}):
        return self.request("POST", "/ssl/certificates", query_params, body)


    def get_ssl_certificates(self, query_params={}):
        return self.request("GET", "/ssl/certificates", query_params)


    def get_plesk_license_types(self, query_params={}):
        return self.request("GET", "/license/plesk-types", query_params)


    def search(self, query_params={}):
        return self.request("GET", "/search", query_params)


    def get_ssl_certificate(self, id, query_params={}):
        return self.request("GET", "/ssl/certificates/{id}".format(id=id), query_params)


    def get_ssl_organisation(self, id, query_params={}):
        return self.request("GET", "/ssl/organisations/{id}".format(id=id), query_params)


    def delete_ssl_organisation(self, id, query_params={}):
        return self.request("DELETE", "/ssl/organisations/{id}".format(id=id), query_params)


    def create_ssl_contact(self, body, query_params={}):
        return self.request("POST", "/ssl/contacts", query_params, body)


    def get_ssl_contacts(self, query_params={}):
        return self.request("GET", "/ssl/contacts", query_params)


    def create_ssl_organisation(self, body, query_params={}):
        return self.request("POST", "/ssl/organisations", query_params, body)


    def get_ssl_organisations(self, query_params={}):
        return self.request("GET", "/ssl/organisations", query_params)


    def get_ssl_type(self, id, query_params={}):
        return self.request("GET", "/ssl/types/{id}".format(id=id), query_params)


    def get_ssl_contact(self, id, query_params={}):
        return self.request("GET", "/ssl/contacts/{id}".format(id=id), query_params)


    def delete_ssl_contact(self, id, query_params={}):
        return self.request("DELETE", "/ssl/contacts/{id}".format(id=id), query_params)


    def create_plesk_license(self, body, query_params={}):
        return self.request("POST", "/licenses/plesk", query_params, body)


    def get_plesk_licenses(self, query_params={}):
        return self.request("GET", "/licenses/plesk", query_params)


    def get_ssl_types(self, query_params={}):
        return self.request("GET", "/ssl/types", query_params)


    def get_plesk_license(self, id, query_params={}):
        return self.request("GET", "/licenses/plesk/{id}".format(id=id), query_params)


    def update_plesk_license(self, id, body, query_params={}):
        return self.request("PUT", "/licenses/plesk/{id}".format(id=id), query_params, body)


    def get_plesk_license_type(self, id, query_params={}):
        return self.request("GET", "/license/plesk-types/{id}".format(id=id), query_params)





import requests


class AuthClient:
    def __init__(self, api_key, base_url="https://auth.lumaserv.com"):
        self.base_url = base_url
        self.session = requests.Session()
        self.session.headers.update({
            'Authorization': 'Bearer ' + api_key,
            'Content-Type': 'application/json'
        })


    def request(self, method, path, params={}, body={}):
        r = self.session.request(method, self.base_url + path, json=body, params=params)
        if r.status_code < 200 or (r.status_code >= 300 and r.status_code < 400):
            raise Exception("Status code is " + r.status_code + "!")
        return r.json()


    def create_project(self, body, query_params={}):
        return self.request("POST", "/projects", query_params, body)


    def get_projects(self, query_params={}):
        return self.request("GET", "/projects", query_params)


    def get_project(self, id, query_params={}):
        return self.request("GET", "/projects/{id}".format(id=id), query_params)


    def delete_project(self, id, query_params={}):
        return self.request("DELETE", "/projects/{id}".format(id=id), query_params)


    def update_project(self, id, body, query_params={}):
        return self.request("PUT", "/projects/{id}".format(id=id), query_params, body)


    def login(self, body, query_params={}):
        return self.request("POST", "/login", query_params, body)


    def create_user(self, body, query_params={}):
        return self.request("POST", "/users", query_params, body)


    def get_users(self, query_params={}):
        return self.request("GET", "/users", query_params)


    def get_user(self, id, query_params={}):
        return self.request("GET", "/users/{id}".format(id=id), query_params)


    def update_user(self, id, body, query_params={}):
        return self.request("PUT", "/users/{id}".format(id=id), query_params, body)


    def request_password_reset(self, body, query_params={}):
        return self.request("POST", "/password-reset", query_params, body)


    def execute_password_reset(self, body, query_params={}):
        return self.request("PUT", "/password-reset", query_params, body)


    def change_email(self, body, query_params={}):
        return self.request("PUT", "/email-change", query_params, body)


    def reject_project_invite(self, id, query_params={}):
        return self.request("POST", "/project-invites/{id}/reject".format(id=id), query_params)


    def insert_audit_log_entry(self, body, query_params={}):
        return self.request("POST", "/audit-log", query_params, body)


    def search_audit_log(self, query_params={}):
        return self.request("GET", "/audit-log", query_params)


    def create_token(self, body, query_params={}):
        return self.request("POST", "/tokens", query_params, body)


    def get_tokens(self, query_params={}):
        return self.request("GET", "/tokens", query_params)


    def get_country(self, code, query_params={}):
        return self.request("GET", "/countries/{code}".format(code=code), query_params)


    def change_password(self, body, query_params={}):
        return self.request("PUT", "/password-change", query_params, body)


    def get_token(self, id, query_params={}):
        return self.request("GET", "/tokens/{id}".format(id=id), query_params)


    def delete_token(self, id, query_params={}):
        return self.request("DELETE", "/tokens/{id}".format(id=id), query_params)


    def delete_project_invite(self, id, query_params={}):
        return self.request("DELETE", "/project-invites/{id}".format(id=id), query_params)


    def validate_token(self, token, query_params={}):
        return self.request("GET", "/validate/{token}".format(token=token), query_params)


    def create_project_invite(self, body, query_params={}):
        return self.request("POST", "/project-invites", query_params, body)


    def get_project_invites(self, query_params={}):
        return self.request("GET", "/project-invites", query_params)


    def add_project_member(self, id, body, query_params={}):
        return self.request("POST", "/projects/{id}/members".format(id=id), query_params, body)


    def get_project_members(self, id, query_params={}):
        return self.request("GET", "/projects/{id}/members".format(id=id), query_params)


    def search_transaction_log(self, body, query_params={}):
        return self.request("POST", "/transaction-log", query_params, body)


    def validate_self(self, query_params={}):
        return self.request("GET", "/validate/self", query_params)


    def accept_project_invite(self, id, query_params={}):
        return self.request("POST", "/project-invites/{id}/accept".format(id=id), query_params)


    def remove_project_member(self, id, user_id, query_params={}):
        return self.request("DELETE", "/projects/{id}/members/{user_id}".format(id=id, user_id=user_id), query_params)


    def get_user_project_memberships(self, id, query_params={}):
        return self.request("GET", "/users/{id}/project_memberships".format(id=id), query_params)


    def get_countries(self, query_params={}):
        return self.request("GET", "/countries", query_params)


